==> io.janusproject.plugin-0.5.3-sources.jar: io/janusproject/services/network/EventEncrypter.java <==
/*
 * $Id$
 *
 * SARL is an general-purpose agent programming language.
 * More details on http://www.sarl.io
 *
 * Copyright (C) 2014-2017 the original authors or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.janusproject.services.network;

import java.util.UUID;

/**
 * An encrypter of events to be published over the network.
 *
 * @author $Author: srodriguez$
 * @version $FullVersion$
 * @mavengroupid $GroupId$
 * @mavenartifactid $ArtifactId$
 */
public interface EventEncrypter {

	/**
	 * Encrypt the given envelope.
	 *
	 * @param envelope - the envelope to encrypt.
	 * @throws Exception - if error when encrypting.
	 */
	void encrypt(EventEnvelope envelope) throws Exception;

	/**
	 * Decrypt the given envelope.
	 *
	 * @param envelope - the envelope to decrypt.
	 * @throws Exception - if error when decrypting.
	 */
	void decrypt(EventEnvelope envelope) throws Exception;

	/**
	 * Encrypt the given UUID.
	 *
	 * @param uuid - the UUID to encrypt.
	 * @return the encrypted UUID.
	 */
	byte[] encryptUUID(UUID uuid);

}

==> io.janusproject.plugin-0.10.1-sources.jar: io/janusproject/services/network/EventEncrypter.java <==
/*
 * $Id$
 *
 * SARL is an general-purpose agent programming language.
 * More details on http://www.sarl.io
 *
 * Copyright (C) 2014-2019 the original authors or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.janusproject.services.network;

import java.util.UUID;

/**
 * An encrypter of events to be published over the network.
 *
 * @author $Author: srodriguez$
 * @version $FullVersion$
 * @mavengroupid $GroupId$
 * @mavenartifactid $ArtifactId$
 */
public interface EventEncrypter {

	/**
	 * Encrypt the given envelope.
	 *
	 * @param envelope the envelope to encrypt.
	 * @throws Exception - if error when encrypting.
	 */
	void encrypt(EventEnvelope envelope) throws Exception;

	/**
	 * Decrypt the given envelope.
	 *
	 * @param envelope the envelope to decrypt.
	 * @throws Exception - if error when decrypting.
	 */
	void decrypt(EventEnvelope envelope) throws Exception;

	/**
	 * Encrypt the given UUID.
	 *
	 * @param uuid the UUID to encrypt.
	 * @return the encrypted UUID.
	 */
	byte[] encryptUUID(UUID uuid);

}
